==> JDFLibJ-2.1.8.3-sources.jar: org/cip4/jdflib/extensions/xjdfwalker/xjdftojdf/WalkXJDF.java <==
/**
 * The CIP4 Software License, Version 1.0
 *
 * Copyright (c) 2001-2016 The International Cooperation for the Integration of Processes in Prepress, Press and Postpress (CIP4). All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the
 * distribution.
 *
 * 3. The end-user documentation included with the redistribution, if any, must include the following acknowledgment: "This product includes software developed by the The International Cooperation for
 * the Integration of Processes in Prepress, Press and Postpress (www.cip4.org)" Alternately, this acknowledgment may appear in the software itself, if and wherever such third-party acknowledgments
 * normally appear.
 *
 * 4. The names "CIP4" and "The International Cooperation for the Integration of Processes in Prepress, Press and Postpress" must not be used to endorse or promote products derived from this software
 * without prior written permission. For written permission, please contact info@cip4.org.
 *
 * 5. Products derived from this software may not be called "CIP4", nor may "CIP4" appear in their name, without prior written permission of the CIP4 organization
 *
 * Usage of this software in commercial products is subject to restrictions. For details please consult info@cip4.org.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE INTERNATIONAL COOPERATION FOR THE INTEGRATION OF PROCESSES IN PREPRESS, PRESS AND POSTPRESS OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
 * OF SUCH DAMAGE. ====================================================================
 *
 * This software consists of voluntary contributions made by many individuals on behalf of the The International Cooperation for the Integration of Processes in Prepress, Press and Postpress and was
 * originally based on software copyright (c) 1999-2001, Heidelberger Druckmaschinen AG copyright (c) 1999-2001, Agfa-Gevaert N.V.
 *
 * For more information on The International Cooperation for the Integration of Processes in Prepress, Press and Postpress , please see <http://www.cip4.org/>.
 *
 *
 */
package org.cip4.jdflib.extensions.xjdfwalker.xjdftojdf;

import org.cip4.jdflib.core.AttributeName;
import org.cip4.jdflib.core.ElementName;
import org.cip4.jdflib.core.JDFElement.EnumNodeStatus;
import org.cip4.jdflib.core.KElement;
import org.cip4.jdflib.extensions.XJDFConstants;
import org.cip4.jdflib.node.JDFNode;
import org.cip4.jdflib.node.JDFNode.EnumType;
import org.cip4.jdflib.util.StringUtil;

/**
 * @author Rainer Prosi, Heidelberger Druckmaschinen walker for the xjdf root
 */
public class WalkXJDF extends WalkXElement
{
	/**
	 *
	 */
	public WalkXJDF()
	{
		super();
	}

	// ///////////////////////////////////////////////////////////////////////////////
	/**
	 * @param xjdf
	 * @return true if must continue
	 */
	@Override
	public KElement walk(final KElement xjdf, final KElement jdf)
	{
		final JDFNode jdfNode = getParentProduct(xjdf, jdf);
		jdfNode.setAttributes(xjdf);
		jdfNode.setVersion(xjdfToJDFImpl.getVersion());
		jdfNode.setMaxVersion(xjdfToJDFImpl.getVersion());
		jdfNode.setStatus(EnumNodeStatus.Part);
		xjdfToJDFImpl.currentJDFNode = jdfNode;
		updateJobID();
		setType();
		updateAttributes(jdfNode);
		return jdfNode;
	}

	/**
	 * @param jdf
	 * @param jdf2
	 * @return
	 */
	private JDFNode getParentProduct(final KElement xjdf, final KElement jdf)
	{
		JDFNode jdfNode = (JDFNode) jdf;
		final String parentID = xjdf.getNonEmpty(XJDFConstants.ParentID);
		if (parentID != null)
		{
			final JDFNode childProduct = (JDFNode) jdfNode.getChildWithAttribute(ElementName.JDF, AttributeName.JOBPARTID, null, parentID, 0, false);

			if (childProduct != null)
			{
				jdfNode = childProduct;
			}
		}
		return jdfNode;
	}

	/**
	 *
	 */
	private void setType()
	{
		final String t = xjdfToJDFImpl.currentJDFNode.getAttribute("Types", null, null);
		if ("Product".equals(t) || StringUtil.isEmpty(t))
		{
			xjdfToJDFImpl.currentJDFNode.setType(EnumType.Product);
			xjdfToJDFImpl.currentJDFNode.removeAttribute("Types");
			xjdfToJDFImpl.foundProduct = true;
			xjdfToJDFImpl.createProduct = true;
		}
		else if (StringUtil.tokenize(t, null, false).size() == 1)
		{
			xjdfToJDFImpl.currentJDFNode.setType(t.trim(), false);
		}
		else
		{
			xjdfToJDFImpl.currentJDFNode.setType(EnumType.ProcessGroup);
		}
	}

	/**
	 *
	 */
	private void updateJobID()
	{
		final JDFNode parentNode = xjdfToJDFImpl.currentJDFNode.getParentJDF();
		if (parentNode != null)
		{
			final String jobID = StringUtil.getNonEmpty(parentNode.getJobID(true));
			final String myJobID = StringUtil.getNonEmpty(xjdfToJDFImpl.currentJDFNode.getJobID(false));
			if (myJobID != null && myJobID.equals(jobID))
			{
				xjdfToJDFImpl.currentJDFNode.removeAttribute(AttributeName.JOBID);
			}
		}
		else
		{
			xjdfToJDFImpl.currentJDFNode.appendAnchor(null);
		}
	}

	/**
	 * @see org.cip4.jdflib.elementwalker.BaseWalker#matches(org.cip4.jdflib.core.KElement)
	 * @param toCheck
	 * @return true if it matches
	 */
	@Override
	public boolean matches(final KElement toCheck)
	{
		return super.matches(toCheck) && XJDFConstants.XJDF.equals(toCheck.getLocalName());
	}

	/**
	 * @see org.cip4.jdflib.extensions.xjdfwalker.xjdftojdf.WalkXElement#updateAttributes(org.cip4.jdflib.core.KElement)
	 */
	@Override
	protected void updateAttributes(final KElement elem)
	{
		elem.removeAttribute(XJDFConstants.ParentID);
		super.updateAttributes(elem);
	}
}

==> JDFLibJ-2.2.8.2-sources.jar: org/cip4/jdflib/extensions/xjdfwalker/xjdftojdf/WalkXJDF.java <==
/**
 * The CIP4 Software License, Version 1.0
 *
 * Copyright (c) 2001-2025 The International Cooperation for the Integration of Processes in Prepress, Press and Postpress (CIP4). All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the
 * distribution.
 *
 * 3. The end-user documentation included with the redistribution, if any, must include the following acknowledgment: "This product includes software developed by the The International Cooperation for
 * the Integration of Processes in Prepress, Press and Postpress (www.cip4.org)" Alternately, this acknowledgment may appear in the software itself, if and wherever such third-party acknowledgments
 * normally appear.
 *
 * 4. The names "CIP4" and "The International Cooperation for the Integration of Processes in Prepress, Press and Postpress" must not be used to endorse or promote products derived from this software
 * without prior written permission. For written permission, please contact info@cip4.org.
 *
 * 5. Products derived from this software may not be called "CIP4", nor may "CIP4" appear in their name, without prior written permission of the CIP4 organization
 *
 * Usage of this software in commercial products is subject to restrictions. For details please consult info@cip4.org.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE INTERNATIONAL COOPERATION FOR THE INTEGRATION OF PROCESSES IN PREPRESS, PRESS AND POSTPRESS OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
 * OF SUCH DAMAGE. ====================================================================
 *
 * This software consists of voluntary contributions made by many individuals on behalf of the The International Cooperation for the Integration of Processes in Prepress, Press and Postpress and was
 * originally based on software copyright (c) 1999-2001, Heidelberger Druckmaschinen AG copyright (c) 1999-2001, Agfa-Gevaert N.V.
 *
 * For more information on The International Cooperation for the Integration of Processes in Prepress, Press and Postpress , please see <http://www.cip4.org/>.
 *
 *
 */
package org.cip4.jdflib.extensions.xjdfwalker.xjdftojdf;

import org.cip4.jdflib.core.AttributeName;
import org.cip4.jdflib.core.ElementName;
import org.cip4.jdflib.core.JDFElement;
import org.cip4.jdflib.core.JDFElement.EnumNodeStatus;
import org.cip4.jdflib.core.KElement;
import org.cip4.jdflib.core.VString;
import org.cip4.jdflib.extensions.XJDFConstants;
import org.cip4.jdflib.node.JDFNode;
import org.cip4.jdflib.node.JDFNode.EnumType;
import org.cip4.jdflib.util.StringUtil;

/**
 * @author Rainer Prosi, Heidelberger Druckmaschinen walker for the xjdf root
 */
public class WalkXJDF extends WalkXElement
{
	/**
	 *
	 */
	public WalkXJDF()
	{
		super();
	}

	// ///////////////////////////////////////////////////////////////////////////////
	/**
	 * @param xjdf
	 * @return true if must continue
	 */
	@Override
	public KElement walk(final KElement xjdf, final KElement jdf)
	{
		final JDFNode jdfNode = getParentProduct(xjdf, jdf);
		jdfNode.setAttributes(xjdf);
		jdfNode.setVersion(xjdfToJDFImpl.getVersion());
		jdfNode.setMaxVersion(xjdfToJDFImpl.getVersion());
		jdfNode.setStatus(EnumNodeStatus.Part);
		xjdfToJDFImpl.currentJDFNode = jdfNode;
		updateJobID();
		setType();
		updateAttributes(jdfNode);
		return jdfNode;
	}

	/**
	 * @param jdf
	 * @param jdf2
	 * @return
	 */
	JDFNode getParentProduct(final KElement xjdf, final KElement jdf)
	{
		JDFNode jdfNode = (JDFNode) jdf;
		final String parentID = xjdf.getNonEmpty(XJDFConstants.ParentID);
		if (parentID != null)
		{
			final JDFNode childProduct = (JDFNode) jdfNode.getChildWithAttribute(ElementName.JDF, AttributeName.JOBPARTID, null, parentID, 0, false);

			if (childProduct != null)
			{
				jdfNode = childProduct;
			}
		}
		return jdfNode;
	}

	/**
	 *
	 */
	private void setType()
	{
		final String t = xjdfToJDFImpl.currentJDFNode.getAttribute("Types", null, null);
		if ("Product".equals(t) || StringUtil.isEmpty(t))
		{
			xjdfToJDFImpl.currentJDFNode.setType(EnumType.Product);
			xjdfToJDFImpl.currentJDFNode.removeAttribute("Types");
			xjdfToJDFImpl.foundProduct = true;
			xjdfToJDFImpl.createProduct = true;
		}
		else if (StringUtil.tokenize(t, null, false).size() == 1)
		{
			xjdfToJDFImpl.currentJDFNode.setType(t.trim(), false);
		}
		else
		{
			xjdfToJDFImpl.currentJDFNode.setType(EnumType.ProcessGroup);
		}
	}

	/**
	 *
	 */
	private void updateJobID()
	{
		final JDFNode parentNode = xjdfToJDFImpl.currentJDFNode.getParentJDF();
		if (parentNode != null)
		{
			final String jobID = StringUtil.getNonEmpty(parentNode.getJobID(true));
			final String myJobID = StringUtil.getNonEmpty(xjdfToJDFImpl.currentJDFNode.getJobID(false));
			if (myJobID != null && myJobID.equals(jobID))
			{
				xjdfToJDFImpl.currentJDFNode.removeAttribute(AttributeName.JOBID);
			}
		}
		else
		{
			xjdfToJDFImpl.currentJDFNode.appendAnchor(null);
		}
	}

	/**
	 * @see org.cip4.jdflib.elementwalker.BaseWalker#matches(org.cip4.jdflib.core.KElement)
	 * @param toCheck
	 * @return true if it matches
	 */
	@Override
	public boolean matches(final KElement toCheck)
	{
		return super.matches(toCheck) && JDFElement.isInXJDFNameSpaceStatic(toCheck);
	}

	/**
	 * @see org.cip4.jdflib.extensions.xjdfwalker.xjdftojdf.WalkXElement#updateAttributes(org.cip4.jdflib.core.KElement)
	 */
	@Override
	protected void updateAttributes(final KElement elem)
	{
		elem.removeAttribute(XJDFConstants.ParentID);
		super.updateAttributes(elem);
	}

	@Override
	public VString getElementNames()
	{
		return new VString(XJDFConstants.XJDF);
	}
}
